@@ -1,6 +1,6 @@
 package Test::PDL;
 {
-  $Test::PDL::VERSION = '0.05';
+  $Test::PDL::VERSION = '0.06';
 }
 
 # ABSTRACT: Test Perl Data Language arrays (a.k.a. piddles) for equality
@@ -99,8 +99,11 @@ sub is_pdl
 {
 	require Test::Builder;
 	my ( $got, $expected, $name ) = @_;
-	$name ||= "piddles are equal";
 	my $tb = Test::Builder->new;
+	if( eval { $name->isa('PDL') } ) {
+		$tb->croak( 'error in arguments: test name is a piddle' );
+	}
+	$name ||= "piddles are equal";
 	if( my $reason = _comparison_fails $got, $expected ) {
 		my $rc = $tb->ok( 0, $name );
 		my $fmt = '%-8T %-12D (%-5S) ';
@@ -180,7 +183,7 @@ Test::PDL - Test Perl Data Language arrays (a.k.a. piddles) for equality
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
